#!/usr/bin/env python

import re

# Section extraction.

sections_regexp_str = r"(?<!{)(?P<section>{(?P<type>[^{}]+)}.*?{(?P=type)})"
sections_regexp = re.compile(sections_regexp_str, re.DOTALL | re.MULTILINE)

# Section inspection.

section_regexp_str = r"{(?P<sectiontype>.*?)}(?P<section>.*){(?P=sectiontype)}"
section_regexp = re.compile(section_regexp_str, re.DOTALL | re.MULTILINE)

def get_regions(s):

    """
    Return a list of regions from 's'. Each region is specified using a tuple of
    the form (type, text).
    """

    last = 0
    regions = []
    for match in sections_regexp.finditer(s):
        start, end = match.span()
        regions.append((None, s[last:start]))
        regions.append(get_section_details(s[start:end]))
        last = end
    regions.append((None, s[last:]))
    return regions

def get_section_details(s):

    "Return the details of a section in the form (type, text)."

    match = section_regexp.match(s)
    if match:
        return match.group("sectiontype"), match.group("section")
    else:
        return None, s

if __name__ == "__main__":
    import sys

    s = sys.stdin.read()

    for type, text in get_regions(s):
        print "Region type:", type
        print "Region:"
        print text
        print
        print "-" * 60

# vim: tabstop=4 expandtab shiftwidth=4
